searchData={"items":[{"type":"module","title":"XmlQuery","doc":"Some simple XML query functions.","ref":"XmlQuery.html"},{"type":"function","title":"XmlQuery.all/2","doc":"Finds all elements in an XML document that match `xpath`, returning a list of records.\nDepending on the given xpath, the type of the record may be different.","ref":"XmlQuery.html#all/2"},{"type":"function","title":"XmlQuery.attr/2","doc":"Returns the value of `attr` from the outermost element of `xml`.","ref":"XmlQuery.html#attr/2"},{"type":"function","title":"XmlQuery.find/2","doc":"Finds the first element, attribute, or element text in `xml` that matches `xpath`.\n\n```elixir\niex> alias XmlQuery, as: Xq\niex> xml = \"\"\"\n...>  \n...>     \n...> \"\"\"\niex> %Xq.Element{name: :child, attributes: [%Xq.Attribute{value: ~c\"oldest\"}]} = Xq.find(xml, \"//child\")\n```","ref":"XmlQuery.html#find/2"},{"type":"function","title":"XmlQuery.find!/2","doc":"Like `find/2` but raises unless exactly one node is found.","ref":"XmlQuery.html#find!/2"},{"type":"macro","title":"XmlQuery.is_xml_struct/1","doc":"","ref":"XmlQuery.html#is_xml_struct/1"},{"type":"function","title":"XmlQuery.parse/1","doc":"Parses an XML document using `:xmerl_scan.string/2`, returning an `XmlQuery.Element` struct.\n\nGiven an xml tuple that has already been created by `:xmerl`, wraps the tuple in an\n`XmlQuery`-specific struct.\n\n```elixir\niex> xml = \"\"\"\n...>  \n...>  \n...> \"\"\"\niex> %Xq.Element{name: :root} = XmlQuery.parse(xml)\n\niex> xml = \"\"\"\n...>  \n...>  \n...> \"\"\"\niex> %Xq.Attribute{name: :property, value: ~c\"root-value\"} = XmlQuery.find(xml, \"//root/@property\") |> XmlQuery.parse()\n```","ref":"XmlQuery.html#parse/1"},{"type":"function","title":"XmlQuery.pretty/1","doc":"Returns `xml` as a prettified string.\n\nElements and text nodes are sorted and indented relative to parent elements.","ref":"XmlQuery.html#pretty/1"},{"type":"function","title":"XmlQuery.text/1","doc":"Returns the text value of `xml`.","ref":"XmlQuery.html#text/1"},{"type":"type","title":"XmlQuery.xml/0","doc":"","ref":"XmlQuery.html#t:xml/0"},{"type":"type","title":"XmlQuery.xml_attribute/0","doc":"","ref":"XmlQuery.html#t:xml_attribute/0"},{"type":"type","title":"XmlQuery.xml_binary/0","doc":"","ref":"XmlQuery.html#t:xml_binary/0"},{"type":"type","title":"XmlQuery.xml_document/0","doc":"","ref":"XmlQuery.html#t:xml_document/0"},{"type":"type","title":"XmlQuery.xml_element/0","doc":"","ref":"XmlQuery.html#t:xml_element/0"},{"type":"type","title":"XmlQuery.xml_text/0","doc":"","ref":"XmlQuery.html#t:xml_text/0"},{"type":"type","title":"XmlQuery.xpath/0","doc":"","ref":"XmlQuery.html#t:xpath/0"},{"type":"module","title":"XmlQuery.Attribute","doc":"","ref":"XmlQuery.Attribute.html"},{"type":"function","title":"XmlQuery.Attribute.new/1","doc":"","ref":"XmlQuery.Attribute.html#new/1"},{"type":"function","title":"XmlQuery.Attribute.pretty/1","doc":"","ref":"XmlQuery.Attribute.html#pretty/1"},{"type":"type","title":"XmlQuery.Attribute.t/0","doc":"","ref":"XmlQuery.Attribute.html#t:t/0"},{"type":"module","title":"XmlQuery.Element","doc":"","ref":"XmlQuery.Element.html"},{"type":"function","title":"XmlQuery.Element.new/1","doc":"","ref":"XmlQuery.Element.html#new/1"},{"type":"function","title":"XmlQuery.Element.pretty/1","doc":"","ref":"XmlQuery.Element.html#pretty/1"},{"type":"type","title":"XmlQuery.Element.t/0","doc":"","ref":"XmlQuery.Element.html#t:t/0"},{"type":"module","title":"XmlQuery.Element.PrettyFormatter","doc":"","ref":"XmlQuery.Element.PrettyFormatter.html"},{"type":"function","title":"XmlQuery.Element.PrettyFormatter.#element#/5","doc":"","ref":"XmlQuery.Element.PrettyFormatter.html##element#/5"},{"type":"function","title":"XmlQuery.Element.PrettyFormatter.#text#/1","doc":"","ref":"XmlQuery.Element.PrettyFormatter.html##text#/1"},{"type":"function","title":"XmlQuery.Element.PrettyFormatter.#xml-inheritance#/0","doc":"","ref":"XmlQuery.Element.PrettyFormatter.html##xml-inheritance#/0"},{"type":"module","title":"XmlQuery.Text","doc":"","ref":"XmlQuery.Text.html"},{"type":"function","title":"XmlQuery.Text.new/1","doc":"","ref":"XmlQuery.Text.html#new/1"},{"type":"function","title":"XmlQuery.Text.pretty/1","doc":"","ref":"XmlQuery.Text.html#pretty/1"},{"type":"type","title":"XmlQuery.Text.t/0","doc":"","ref":"XmlQuery.Text.html#t:t/0"},{"type":"module","title":"XmlQuery.Xmerl","doc":"","ref":"XmlQuery.Xmerl.html"},{"type":"macro","title":"XmlQuery.Xmerl.xmlAttribute/1","doc":"","ref":"XmlQuery.Xmerl.html#xmlAttribute/1"},{"type":"macro","title":"XmlQuery.Xmerl.xmlAttribute/2","doc":"","ref":"XmlQuery.Xmerl.html#xmlAttribute/2"},{"type":"macro","title":"XmlQuery.Xmerl.xmlDocument/1","doc":"","ref":"XmlQuery.Xmerl.html#xmlDocument/1"},{"type":"macro","title":"XmlQuery.Xmerl.xmlDocument/2","doc":"","ref":"XmlQuery.Xmerl.html#xmlDocument/2"},{"type":"macro","title":"XmlQuery.Xmerl.xmlElement/1","doc":"","ref":"XmlQuery.Xmerl.html#xmlElement/1"},{"type":"macro","title":"XmlQuery.Xmerl.xmlElement/2","doc":"","ref":"XmlQuery.Xmerl.html#xmlElement/2"},{"type":"macro","title":"XmlQuery.Xmerl.xmlText/1","doc":"","ref":"XmlQuery.Xmerl.html#xmlText/1"},{"type":"macro","title":"XmlQuery.Xmerl.xmlText/2","doc":"","ref":"XmlQuery.Xmerl.html#xmlText/2"},{"type":"type","title":"XmlQuery.Xmerl.xml_attribute/0","doc":"","ref":"XmlQuery.Xmerl.html#t:xml_attribute/0"},{"type":"type","title":"XmlQuery.Xmerl.xml_document/0","doc":"","ref":"XmlQuery.Xmerl.html#t:xml_document/0"},{"type":"type","title":"XmlQuery.Xmerl.xml_element/0","doc":"","ref":"XmlQuery.Xmerl.html#t:xml_element/0"},{"type":"type","title":"XmlQuery.Xmerl.xml_text/0","doc":"","ref":"XmlQuery.Xmerl.html#t:xml_text/0"},{"type":"exception","title":"XmlQuery.QueryError","doc":"An exception raised when unable to find an XML element.","ref":"XmlQuery.QueryError.html"},{"type":"extras","title":"XmlQuery","doc":"# XmlQuery\n\nSome simple XML query functions. Delegates much of its work to `:xmerl`, but provides\nan API similar to `HtmlQuery`.\n\n```elixir\niex> alias XmlQuery, to: Xq\n\niex> xml = \"\"\"\n \n \n   \n   \n     \n       \n         Leg \n         Lion \n         Blue \n       \n     \n   \n \n\"\"\"\n\niex> xml |> Xq.all(\"//child\") |> Enum.map(&Xq.attr(&1, \"age\"))\n[\"12\", \"9\"]\n\niex> xml |> Xq.find!(\"//toy\") |> Xq.text()\n\"Leg Lion Blue\"\n\niex> xml |> Xq.find!(\"//toy/animal\") |> Xq.text()\n\"Lion\"\n```","ref":"readme.html"},{"type":"extras","title":"API Docs - XmlQuery","doc":"See the documentation for the main `XmlQuery` module for details and more examples:","ref":"readme.html#api-docs"},{"type":"extras","title":"Installation - XmlQuery","doc":"```elixir\ndef deps do\n  [\n    {:xml_query, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Development - XmlQuery","doc":"```shell\nbrew bundle\n\nbin/dev/doctor\nbin/dev/update\nbin/dev/audit\nbin/dev/shipit\n```","ref":"readme.html#development"},{"type":"extras","title":"References - XmlQuery","doc":"- https://gist.github.com/sasa1977/5967224\n- https://medium.com/erlang-battleground/the-hidden-xml-simplifier-a5f66e10c928","ref":"readme.html#references"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"}],"content_type":"text/markdown"}